@@ -6,45 +6,6 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
-"""
-The "BaseAction" module lets you define some actions on the underlying power _grid.
-These actions are either made by an agent, or by the environment.
-
-For now, the actions can act on:
-
-  - the "injections" and allows you to change:
-
-    - the generators active power production setpoint
-    - the generators voltage magnitude setpoint
-    - the loads active power consumption
-    - the loads reactive power consumption
-
-  - the status of the powerlines (connected/disconnected)
-  - the configuration at substations eg setting different objects to different buses for example
-
-The BaseAction class is abstract. You can implement it the way you want. If you decide to extend it, make sure
-that the :class:`grid2op.Backend` class will be able to understand it. If you don't, your extension will not affect the
-underlying powergrid. Indeed a :class:`grid2op.Backend` will call the :func:`BaseAction.__call__` method and should
-understands its return type.
-
-In this module we derived two action class:
-
-  - :class:`BaseAction` represents a type of action that can act on all the above-mentioned objects
-  - :class:`TopologyAction` restricts the modification to line status modification and bus reconfiguration at substations.
-
-
-The :class:`BaseAction` and all its derivatives also offer some usefull inspection utilities:
-
-  - :func:`BaseAction.__str__` prints the action in a format that gives usefull information on how it will affect the powergrid
-  - :func:`BaseAction.effect_on` returns a dictionnary that gives information about its effect.
-
-Finally, :class:`BaseAction` class define some strict behavior to follow if reimplementing them. The correctness of each
-instances of BaseAction is assessed both when calling :func:`BaseAction.update` or with a call to
-:func:`BaseAction._check_for_ambiguity` performed for example by the Backend when it must implement its effect on the
-powergrid through a call to :func:`BaseAction.__call__`
-
-"""
-
 
 import numpy as np
 import warnings
@@ -337,8 +298,10 @@ class BaseAction(GridObjects):
         In case of "switch" as we see here, the action can be ambiguous, but not ambiguous *per se*. This method
         will **never** throw any error in this case.
 
-        Returns
+        Raises
         -------
+        :class:`grid2op.Exceptions.AmbiguousAction`
+            Or any of its more precise subclasses, depending on which assumption is not met.
 
         """
         self._check_for_ambiguity()
