@@ -1,9 +1,9 @@
 __all__ = [
-    "BasicEnv", 
+    "BaseEnv",
     "Environment",
-    "MultiEnv"
+    "MultiEnvironment"
 ]
 
-from grid2op.Environment.BasicEnv import _BasicEnv
+from grid2op.Environment.BaseEnv import BaseEnv
 from grid2op.Environment.Environment import Environment
 from grid2op.Environment.MultiEnv import MultiEnvironment
