@@ -10,10 +10,13 @@ from grid2op.Reward.BaseReward import BaseReward
 
 
 class CombinedReward(BaseReward):
+    """
+    This class allows to combine multiple rewards, by summing them for example.
+    """
     def __init__(self):
         BaseReward.__init__(self)
-        self.reward_min = 0
-        self.reward_max = 0
+        self.reward_min = 0.0
+        self.reward_max = 0.0
         self.rewards = {}
 
     def addReward(self, reward_name, reward_instance, reward_weight = 1.0):
@@ -35,9 +38,19 @@ class CombinedReward(BaseReward):
             return True
         return False
 
+    def __iter__(self):
+        for k, v in self.rewards.items():
+            r_dict = dict(v["instance"])
+            r_dict["weight"] = v["weight"]
+            yield (k, r_dict)
+
     def initialize(self, env):
         for key, reward in self.rewards.items():
-            reward.initialize(env)
+            reward_w = reward["weight"]
+            reward_instance = reward["instance"]
+            reward_instance.initialize(env)
+            self.reward_max += reward_instance.reward_max * reward_w
+            self.reward_min += reward_instance.reward_min * reward_w
 
     def __call__(self, action, env, has_error, is_done, is_illegal, is_ambiguous):
         res = 0.0
