@@ -5,28 +5,15 @@
 # you can obtain one at http://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
-
-"""
-This module is here to facilitate the evaluation of agent.
-It can handles all types of :class:`grid2op.BaseAgent`.
-
-"""
 import time
 import warnings
 
 import numpy as np
 import copy
 
-import os
-import sys
-
 from multiprocessing import Pool
 
-import json
-
 import pdb
-
-# from grid2op.BaseAction import HelperAction, BaseAction, TopologyAction
 from grid2op.Action import BaseAction, TopologyAction, DontAct
 from grid2op.Exceptions import *
 from grid2op.Observation import CompleteObservation, BaseObservation
@@ -445,7 +432,7 @@ class Runner(object):
         self.voltageControlerClass = voltageControlerClass
         self._other_rewards = other_rewards
 
-        # for opponent (should be defined here) after the initialization of _BasicEnv
+        # for opponent (should be defined here) after the initialization of BaseEnv
         if not issubclass(opponent_action_class, BaseAction):
             raise EnvError("Impossible to make an environment with an opponent action class not derived from BaseAction")
         try:
@@ -561,7 +548,7 @@ class Runner(object):
         # the "-1" above is because the environment will be reset. So it will increase id of 1.
         obs = env.reset()
         # reset the agent
-        agent.reset()
+        agent.reset(obs)
 
         # compute the size and everything if it needs to be stored
         nb_timestep_max = env.chronics_handler.max_timestep()
@@ -852,21 +839,20 @@ class Runner(object):
 
         """
         if nb_episode < 0:
-            raise RuntimeError(
-                "Impossible to run a negative number of scenarios.")
+            raise RuntimeError("Impossible to run a negative number of scenarios.")
+
         if nb_episode == 0:
             res = []
         else:
             if nb_process <= 0:
-                raise RuntimeError(
-                    "Impossible to run using less than 1 process.")
+                raise RuntimeError("Impossible to run using less than 1 process.")
             if max_iter is not None:
                 self.chronics_handler.set_max_iter(max_iter)
+
             if nb_process == 1:
                 self.logger.info("Sequential runner used.")
                 res = self.run_sequential(nb_episode, path_save=path_save, pbar=pbar)
             else:
-                self.logger.info("Parrallel runner used.")
-                res = self.run_parrallel(
-                    nb_episode, nb_process=nb_process, path_save=path_save)
+                self.logger.info("Parallel runner used.")
+                res = self.run_parrallel(nb_episode, nb_process=nb_process, path_save=path_save)
         return res
