@@ -3,7 +3,7 @@ Grid2Op
 Document will be made later on.
 
 """
-__version__ = '0.6.1'
+__version__ = '0.7.0'
 
 __all__ = [
     "Action",
@@ -17,16 +17,17 @@ __all__ = [
     "Rules",
     "Reward",
     "Runner",
-    "main",
     "Utils",
     "Plot",
     "EpisodeData",
     "Download",
     "VoltageControler",
-    "tests"
+    "tests",
+    "main",
+    "command_line"
 ]
 
-from grid2op.MakeEnv import make
+from grid2op.MakeEnv import make, make2
 
 # TODO remove -- Export hardcoded datasets settings at top-level
 from grid2op.MakeEnv import CASE_14_FILE
