@@ -20,7 +20,7 @@ import pdb
 from grid2op.tests.helper_path_test import *
 
 from grid2op.Exceptions import *
-from grid2op.Observation import ObservationSpace, CompleteObservation, ObsEnv, BaseObservation
+from grid2op.Observation import ObservationSpace, CompleteObservation, _ObsEnv, BaseObservation
 from grid2op.Chronics import ChronicsHandler, ChangeNothing, GridStateFromFile, GridStateFromFileWithForecasts
 from grid2op.Action import ActionSpace
 from grid2op.Rules import RulesChecker
